@@ -324,7 +324,6 @@ class MultiBot(Generic[T], ABC):
                 await self.send_negative(message)
                 return OrderedSet()
 
-        await flanautils.do_later(constants.COMMAND_MESSAGE_DURATION, self.delete_message, message)
         return users - bot_user
 
     @abstractmethod
@@ -562,7 +561,7 @@ class MultiBot(Generic[T], ABC):
     @group
     @bot_mentioned
     async def _on_users(self, message: Message):
-        role_names = [role.name for role in await self.get_roles(message.chat.group_id)]
+        role_names = [role.name for role in await self.get_group_roles(message.chat.group_id)]
         role_names.remove('@everyone')
 
         user_names = [f'<@{user.id}>' for user in await self.find_users_by_roles([], message)]
@@ -605,6 +604,9 @@ class MultiBot(Generic[T], ABC):
     async def accept_button_event(self, event: constants.MESSAGE_EVENT | Message):
         pass
 
+    async def add_role(self, user: int | str | User, group_: int | str | Chat | Message, role: int | str | Role):
+        pass
+
     async def ban(self, user: int | str | User, group_: int | str | Chat | Message, time: int | datetime.timedelta = None, message: Message = None):
         # noinspection PyTypeChecker
         ban = Ban(self.platform, self.get_user_id(user), self.get_group_id(group_), time)
@@ -623,6 +625,19 @@ class MultiBot(Generic[T], ABC):
         kwargs |= {'edit': True}
         return await self.send(*args, **kwargs)
 
+    @return_if_first_empty(exclude_self_types='MultiBot', globals_=globals())
+    async def find_role(self, role: int | str | Role, group_: int | str | Chat | Message) -> Role | None:
+        if isinstance(role, Role):
+            return role
+
+        roles = await self.get_group_roles(group_)
+
+        match role:
+            case int(role_id):
+                return flanautils.find(roles, condition=lambda role_: role_.id == role_id)
+            case str(role_name):
+                return flanautils.find(roles, condition=lambda role_: role_.name == role_name)
+
     async def find_users_by_roles(self, roles: Iterable[int | str | Role], group_: int | str | Chat | Message) -> list[User]:
         pass
 
@@ -668,20 +683,7 @@ class MultiBot(Generic[T], ABC):
         pass
 
     @return_if_first_empty(exclude_self_types='MultiBot', globals_=globals())
-    async def get_role(self, role: int | str | Role, group_: int | str | Chat | Message) -> Role | None:
-        if isinstance(role, Role):
-            return role
-
-        roles = await self.get_roles(group_)
-
-        match role:
-            case int(role_id):
-                return flanautils.find(roles, condition=lambda role_: role_.id == role_id)
-            case str(role_name):
-                return flanautils.find(roles, condition=lambda role_: role_.name == role_name)
-
-    @return_if_first_empty(exclude_self_types='MultiBot', globals_=globals())
-    async def get_roles(self, group_: int | str | Chat | Message) -> list[Role]:
+    async def get_group_roles(self, group_: int | str | Chat | Message) -> list[Role]:
         pass
 
     @return_if_first_empty(exclude_self_types='MultiBot', globals_=globals())
@@ -771,6 +773,9 @@ class MultiBot(Generic[T], ABC):
 
         return decorator(func_) if func_ else decorator
 
+    async def remove_role(self, user: int | str | User, group_: int | str | Chat | Message, role: int | str | Role):
+        pass
+
     @abstractmethod
     @parse_arguments
     async def send(
